#include "./generator-rf.h"
#include <random>
#include <stdexcept>
namespace mri {
  // ********************************************************************** //
  // ********************************************************************** //
  // ********************************************************************** //
  void GeneratorRF::SetAmplitudes(std::vector<double> amplitudes){
    if (amplitudes.size() != voxel_num_)
      throw std::invalid_argument("Number of amplitudes do not fit number of voxels");    
    amplitudes_ = amplitudes;
  };
  // ********************************************************************** //
  // ********************************************************************** //
  // ********************************************************************** //
  void GeneratorRF::SetT2sDecays(std::vector<double> T2s_decays){
    T2s_decays_ = T2s_decays;
  };
  // ********************************************************************** //
  // ********************************************************************** //
  // ********************************************************************** //
  // period is set in milliseconds (ms)
  void GeneratorRF::SetTimer(long total_periods, double period_ms,
                             int samples_per_period) {
    total_periods_ = total_periods;
    period_ms_ = period_ms;
    samples_per_period_ = samples_per_period;
    omega_ = 2.0*PI_/period_ms_;
    long total_samples = total_periods * samples_per_period;
    timesteps_.resize(total_samples);
    double a_timestep = period_ms/samples_per_period;
    for (long i = 0; i < total_samples; ++i) {
      timesteps_[i] = i*a_timestep;      
    }
    // for (double step: timesteps_) std::cout << step<<' ';
    // std::cout<<std::endl;
  };

  // ********************************************************************** //
  // ********************************************************************** //
  // ********************************************************************** //
  void GeneratorRF::SetVoxels(double voxel_num, double phase_init,
                              double phase_range) {
    voxel_num_ = voxel_num;
    phase_init_ = phase_init;
    phase_range_ = phase_range;
  };
  // ********************************************************************** //
  // ********************************************************************** //
  // ********************************************************************** //

}  // end of namespace mri
